@@ -162,7 +162,7 @@ class Remote:
         pass
 
     def exist_repo_branches(self, repo_branch:str):
-        self.branches = self.gh_repo.get_branches()
+        self.branches = [obj.name for obj in self.gh_repo.get_branches()]
         flag = repo_branch in self.branches
         logger.info(f"{self.repo_branch}" + ("in" if flag else " not in ") +f"Remote repo branch: {self.branches}")
         return flag
